@@ -40,7 +40,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ApplySnapshot", params)
+            headers = request.headers
+            body = self.call("ApplySnapshot", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ApplySnapshotResponse()
@@ -71,7 +72,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AttachDisks", params)
+            headers = request.headers
+            body = self.call("AttachDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AttachDisksResponse()
@@ -102,7 +104,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("BindAutoSnapshotPolicy", params)
+            headers = request.headers
+            body = self.call("BindAutoSnapshotPolicy", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.BindAutoSnapshotPolicyResponse()
@@ -133,7 +136,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CopySnapshotCrossRegions", params)
+            headers = request.headers
+            body = self.call("CopySnapshotCrossRegions", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CopySnapshotCrossRegionsResponse()
@@ -164,7 +168,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAutoSnapshotPolicy", params)
+            headers = request.headers
+            body = self.call("CreateAutoSnapshotPolicy", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAutoSnapshotPolicyResponse()
@@ -196,7 +201,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDisks", params)
+            headers = request.headers
+            body = self.call("CreateDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDisksResponse()
@@ -228,7 +234,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateSnapshot", params)
+            headers = request.headers
+            body = self.call("CreateSnapshot", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateSnapshotResponse()
@@ -258,7 +265,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAutoSnapshotPolicies", params)
+            headers = request.headers
+            body = self.call("DeleteAutoSnapshotPolicies", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAutoSnapshotPoliciesResponse()
@@ -289,7 +297,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSnapshots", params)
+            headers = request.headers
+            body = self.call("DeleteSnapshots", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSnapshotsResponse()
@@ -320,7 +329,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAutoSnapshotPolicies", params)
+            headers = request.headers
+            body = self.call("DescribeAutoSnapshotPolicies", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAutoSnapshotPoliciesResponse()
@@ -348,7 +358,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDiskAssociatedAutoSnapshotPolicy", params)
+            headers = request.headers
+            body = self.call("DescribeDiskAssociatedAutoSnapshotPolicy", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDiskAssociatedAutoSnapshotPolicyResponse()
@@ -376,7 +387,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDiskConfigQuota", params)
+            headers = request.headers
+            body = self.call("DescribeDiskConfigQuota", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDiskConfigQuotaResponse()
@@ -404,7 +416,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDiskOperationLogs", params)
+            headers = request.headers
+            body = self.call("DescribeDiskOperationLogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDiskOperationLogsResponse()
@@ -435,7 +448,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDiskStoragePool", params)
+            headers = request.headers
+            body = self.call("DescribeDiskStoragePool", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDiskStoragePoolResponse()
@@ -466,7 +480,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDisks", params)
+            headers = request.headers
+            body = self.call("DescribeDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDisksResponse()
@@ -496,7 +511,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstancesDiskNum", params)
+            headers = request.headers
+            body = self.call("DescribeInstancesDiskNum", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstancesDiskNumResponse()
@@ -526,7 +542,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSnapshotOperationLogs", params)
+            headers = request.headers
+            body = self.call("DescribeSnapshotOperationLogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSnapshotOperationLogsResponse()
@@ -554,7 +571,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSnapshotSharePermission", params)
+            headers = request.headers
+            body = self.call("DescribeSnapshotSharePermission", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSnapshotSharePermissionResponse()
@@ -585,7 +603,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSnapshots", params)
+            headers = request.headers
+            body = self.call("DescribeSnapshots", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSnapshotsResponse()
@@ -616,7 +635,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DetachDisks", params)
+            headers = request.headers
+            body = self.call("DetachDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DetachDisksResponse()
@@ -644,7 +664,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetSnapOverview", params)
+            headers = request.headers
+            body = self.call("GetSnapOverview", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetSnapOverviewResponse()
@@ -676,7 +697,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InitializeDisks", params)
+            headers = request.headers
+            body = self.call("InitializeDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InitializeDisksResponse()
@@ -704,7 +726,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquirePriceModifyDiskExtraPerformance", params)
+            headers = request.headers
+            body = self.call("InquirePriceModifyDiskExtraPerformance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquirePriceModifyDiskExtraPerformanceResponse()
@@ -734,7 +757,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceCreateDisks", params)
+            headers = request.headers
+            body = self.call("InquiryPriceCreateDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceCreateDisksResponse()
@@ -766,7 +790,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceRenewDisks", params)
+            headers = request.headers
+            body = self.call("InquiryPriceRenewDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceRenewDisksResponse()
@@ -796,7 +821,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceResizeDisk", params)
+            headers = request.headers
+            body = self.call("InquiryPriceResizeDisk", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceResizeDiskResponse()
@@ -827,7 +853,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAutoSnapshotPolicyAttribute", params)
+            headers = request.headers
+            body = self.call("ModifyAutoSnapshotPolicyAttribute", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAutoSnapshotPolicyAttributeResponse()
@@ -857,7 +884,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDiskAttributes", params)
+            headers = request.headers
+            body = self.call("ModifyDiskAttributes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDiskAttributesResponse()
@@ -887,7 +915,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDiskExtraPerformance", params)
+            headers = request.headers
+            body = self.call("ModifyDiskExtraPerformance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDiskExtraPerformanceResponse()
@@ -921,7 +950,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDisksChargeType", params)
+            headers = request.headers
+            body = self.call("ModifyDisksChargeType", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDisksChargeTypeResponse()
@@ -949,7 +979,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDisksRenewFlag", params)
+            headers = request.headers
+            body = self.call("ModifyDisksRenewFlag", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDisksRenewFlagResponse()
@@ -980,7 +1011,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySnapshotAttribute", params)
+            headers = request.headers
+            body = self.call("ModifySnapshotAttribute", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySnapshotAttributeResponse()
@@ -1014,7 +1046,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySnapshotsSharePermission", params)
+            headers = request.headers
+            body = self.call("ModifySnapshotsSharePermission", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySnapshotsSharePermissionResponse()
@@ -1045,7 +1078,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RenewDisk", params)
+            headers = request.headers
+            body = self.call("RenewDisk", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RenewDiskResponse()
@@ -1076,7 +1110,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ResizeDisk", params)
+            headers = request.headers
+            body = self.call("ResizeDisk", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ResizeDiskResponse()
@@ -1108,7 +1143,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("TerminateDisks", params)
+            headers = request.headers
+            body = self.call("TerminateDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.TerminateDisksResponse()
@@ -1139,7 +1175,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UnbindAutoSnapshotPolicy", params)
+            headers = request.headers
+            body = self.call("UnbindAutoSnapshotPolicy", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UnbindAutoSnapshotPolicyResponse()
